@@ -1,12 +1,12 @@
 package File::Move::Undoable;
 
-our $DATE = '2016-06-10'; # DATE
-our $VERSION = '0.08'; # VERSION
+our $DATE = '2017-07-10'; # DATE
+our $VERSION = '0.09'; # VERSION
 
 use 5.010001;
 use strict;
 use warnings;
-use Log::Any::IfLOG '$log';
+use Log::ger;
 
 use File::MoreUtil qw(file_exists l_abs_path);
 use File::Trash::Undoable;
@@ -107,10 +107,10 @@ sub mv {
     my $mptarget = Sys::Filesystem::MountPoint::path_to_mount_point($atarget);
     my $same_fs  = $mpsource eq $mptarget;
     if ($same_fs) {
-        $log->tracef("Source %s & target %s are on the same filesystem (%s)",
+        log_trace("Source %s & target %s are on the same filesystem (%s)",
                      $source, $target, $mpsource);
     } else {
-        $log->tracef("Source %s and target %s are on different filesystems ".
+        log_trace("Source %s and target %s are on different filesystems ".
                          "(%s and %s)", $source, $target, $mpsource, $mptarget);
     }
 
@@ -134,7 +134,7 @@ sub mv {
             );
         }
 
-        $log->info("(DRY) ".($te ? "Continue moving" : "Moving").
+        log_info("(DRY) ".($te ? "Continue moving" : "Moving").
                        " $source -> $target ...") if $dry_run;
         return [200, "$source needs to be ".
                     ($te ? "continued to be moved":"moved")." to $target",
@@ -142,7 +142,7 @@ sub mv {
 
     } elsif ($tx_action eq 'fix_state') {
         if ($same_fs) {
-            $log->infof("Renaming %s -> %s ...", $source, $target);
+            log_info("Renaming %s -> %s ...", $source, $target);
             if (rename $source, $target) {
                 return [200, "OK"];
             } else {
@@ -150,7 +150,7 @@ sub mv {
             }
         } else {
             my @cmd = ("rsync", @$rsync_opts, "$source/", "$target/");
-            $log->infof("Rsync-ing %s -> %s ...", $source, $target);
+            log_info("Rsync-ing %s -> %s ...", $source, $target);
             system @cmd;
             return [500, "rsync: ".explain_child_error($?)] if $?;
             return File::Trash::Undoable::trash(
@@ -176,12 +176,16 @@ File::Move::Undoable - Move file/directory using rename/rsync, with undo support
 
 =head1 VERSION
 
-This document describes version 0.08 of File::Move::Undoable (from Perl distribution File-Move-Undoable), released on 2016-06-10.
+This document describes version 0.09 of File::Move::Undoable (from Perl distribution File-Move-Undoable), released on 2017-07-10.
 
 =head1 FUNCTIONS
 
 
-=head2 mv(%args) -> [status, msg, result, meta]
+=head2 mv
+
+Usage:
+
+ mv(%args) -> [status, msg, result, meta]
 
 Move file/directory using rename/rsync, with undo support.
 
@@ -304,7 +308,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2017, 2016, 2015, 2014, 2012 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
